@@ -4,43 +4,41 @@ from typing import Annotated, Literal
 
 from pydantic import BaseModel, ConfigDict, Field
 
-from notionary.blocks.enums import BlockColor, BlockType, CodingLanguage, FileType
-from notionary.blocks.rich_text.models import RichText
+from notionary.blocks.enums import BlockColor, BlockType, CodingLanguage
+from notionary.rich_text.schemas import RichText
+from notionary.shared.models.file import ExternalFile, FileUploadFile, NotionHostedFile
 from notionary.shared.models.icon import Icon
 from notionary.shared.models.parent import Parent
 from notionary.user.schemas import PartialUserDto
 
 # ============================================================================
-# File-related models
+# File Data wrapper with caption
 # ============================================================================
 
 
-class ExternalFile(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    url: str
-
-
-class NotionHostedFile(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    url: str
-    expiry_time: str
-
-
-class FileUploadFile(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    id: str
-
-
-class FileData(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
+class CaptionMixin(BaseModel):
     caption: list[RichText] = Field(default_factory=list)
-    type: FileType
-    external: ExternalFile | None = None
-    file: NotionHostedFile | None = None
-    file_upload: FileUploadFile | None = None
     name: str | None = None
 
 
+class ExternalFileWithCaption(CaptionMixin, ExternalFile):
+    pass
+
+
+class NotionHostedFileWithCaption(CaptionMixin, NotionHostedFile):
+    pass
+
+
+class FileUploadFileWithCaption(CaptionMixin, FileUploadFile):
+    pass
+
+
+type FileWithCaption = Annotated[
+    ExternalFileWithCaption | NotionHostedFileWithCaption | FileUploadFileWithCaption,
+    Field(discriminator="type"),
+]
+
+
 # ============================================================================
 # Base Block
 # ============================================================================
@@ -65,24 +63,14 @@ class BaseBlock(BaseModel):
 # ============================================================================
 
 
-class AudioData(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    caption: list[RichText] = Field(default_factory=list)
-    type: FileType
-    external: ExternalFile | None = None
-    file: NotionHostedFile | None = None
-    file_upload: FileUploadFile | None = None
-    name: str | None = None
-
-
 class AudioBlock(BaseBlock):
     type: Literal[BlockType.AUDIO] = BlockType.AUDIO
-    audio: AudioData
+    audio: FileWithCaption
 
 
 class CreateAudioBlock(BaseModel):
     type: Literal[BlockType.AUDIO] = BlockType.AUDIO
-    audio: AudioData
+    audio: FileWithCaption
 
 
 # ============================================================================
@@ -90,8 +78,7 @@ class CreateAudioBlock(BaseModel):
 # ============================================================================
 
 
-class BookmarkData(BaseModel):
-    caption: list[RichText] = Field(default_factory=list)
+class BookmarkData(CaptionMixin):
     url: str
 
 
@@ -224,8 +211,7 @@ class CreateChildDatabaseBlock(BaseModel):
 # ============================================================================
 
 
-class CodeData(BaseModel):
-    caption: list[RichText] = Field(default_factory=list)
+class CodeData(CaptionMixin):
     rich_text: list[RichText]
     language: CodingLanguage = CodingLanguage.PLAIN_TEXT
 
@@ -311,9 +297,8 @@ class CreateDividerBlock(BaseModel):
 # ============================================================================
 
 
-class EmbedData(BaseModel):
+class EmbedData(CaptionMixin):
     url: str
-    caption: list[RichText] = Field(default_factory=list)
 
 
 class EmbedBlock(BaseBlock):
@@ -352,12 +337,12 @@ class CreateEquationBlock(BaseModel):
 
 class FileBlock(BaseBlock):
     type: Literal[BlockType.FILE] = BlockType.FILE
-    file: FileData
+    file: FileWithCaption
 
 
 class CreateFileBlock(BaseModel):
     type: Literal[BlockType.FILE] = BlockType.FILE
-    file: FileData
+    file: FileWithCaption
 
 
 # ============================================================================
@@ -416,24 +401,14 @@ CreateHeadingBlock = CreateHeading1Block | CreateHeading2Block | CreateHeading3B
 # ============================================================================
 
 
-class ImageData(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    caption: list[RichText] = Field(default_factory=list)
-    type: FileType
-    external: ExternalFile | None = None
-    file: NotionHostedFile | None = None
-    file_upload: FileUploadFile | None = None
-    name: str | None = None
-
-
 class ImageBlock(BaseBlock):
     type: Literal[BlockType.IMAGE] = BlockType.IMAGE
-    image: ImageData
+    image: FileWithCaption
 
 
 class CreateImageBlock(BaseModel):
     type: Literal[BlockType.IMAGE] = BlockType.IMAGE
-    image: ImageData
+    image: FileWithCaption
 
 
 # ============================================================================
@@ -497,24 +472,14 @@ class CreateParagraphBlock(BaseModel):
 # ============================================================================
 
 
-class PdfData(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    caption: list[RichText] = Field(default_factory=list)
-    type: FileType
-    external: ExternalFile | None = None
-    file: NotionHostedFile | None = None
-    file_upload: FileUploadFile | None = None
-    name: str | None = None
-
-
 class PdfBlock(BaseBlock):
     type: Literal[BlockType.PDF] = BlockType.PDF
-    pdf: PdfData
+    pdf: FileWithCaption
 
 
 class CreatePdfBlock(BaseModel):
     type: Literal[BlockType.PDF] = BlockType.PDF
-    pdf: PdfData
+    pdf: FileWithCaption
 
 
 # ============================================================================
@@ -669,31 +634,97 @@ class CreateToggleBlock(BaseModel):
 # ============================================================================
 
 
-class VideoData(BaseModel):
-    model_config = ConfigDict(from_attributes=True)
-    caption: list[RichText] = Field(default_factory=list)
-    type: FileType
-    external: ExternalFile | None = None
-    file: NotionHostedFile | None = None
-    file_upload: FileUploadFile | None = None
-    name: str | None = None
-
-
 class VideoBlock(BaseBlock):
     type: Literal[BlockType.VIDEO] = BlockType.VIDEO
-    video: VideoData
+    video: FileWithCaption
 
 
 class CreateVideoBlock(BaseModel):
     type: Literal[BlockType.VIDEO] = BlockType.VIDEO
-    video: VideoData
+    video: FileWithCaption
+
+
+# ============================================================================
+# Synced Block
+# ============================================================================
+
+
+class SyncedFromBlock(BaseModel):
+    type: Literal["block_id"] = "block_id"
+    block_id: str
+
+
+class SyncedBlockData(BaseModel):
+    synced_from: SyncedFromBlock | None = None
+    children: list[Block] | None = None
+
+
+class SyncedBlockBlock(BaseBlock):
+    type: Literal[BlockType.SYNCED_BLOCK] = BlockType.SYNCED_BLOCK
+    synced_block: SyncedBlockData
+
+
+class CreateSyncedBlockData(BaseModel):
+    synced_from: SyncedFromBlock | None = None
+    children: list[BlockCreatePayload] | None = None
+
+
+class CreateSyncedBlockBlock(BaseModel):
+    type: Literal[BlockType.SYNCED_BLOCK] = BlockType.SYNCED_BLOCK
+    synced_block: CreateSyncedBlockData
+
+
+# ============================================================================
+# Link Preview Block (Read-Only)
+# ============================================================================
+
+
+class LinkPreviewData(BaseModel):
+    url: str
+
+
+class LinkPreviewBlock(BaseBlock):
+    type: Literal[BlockType.LINK_PREVIEW] = BlockType.LINK_PREVIEW
+    link_preview: LinkPreviewData
+
+
+# ============================================================================
+# Link To Page Block
+# ============================================================================
+
+
+class LinkToPageData(BaseModel):
+    type: Literal["page_id", "database_id", "comment_id"]
+    page_id: str | None = None
+    database_id: str | None = None
+    comment_id: str | None = None
+
+
+class LinkToPageBlock(BaseBlock):
+    type: Literal[BlockType.LINK_TO_PAGE] = BlockType.LINK_TO_PAGE
+    link_to_page: LinkToPageData
+
+
+class CreateLinkToPageBlock(BaseModel):
+    type: Literal[BlockType.LINK_TO_PAGE] = BlockType.LINK_TO_PAGE
+    link_to_page: LinkToPageData
+
+
+# ============================================================================
+# Unsupported Block
+# ============================================================================
+
+
+class UnsupportedBlock(BaseBlock):
+    type: Literal[BlockType.UNSUPPORTED] = BlockType.UNSUPPORTED
+    unsupported: dict = {}
 
 
 # ============================================================================
 # Block Union Type
 # ============================================================================
 
-Block = Annotated[
+type Block = Annotated[
     (
         AudioBlock
         | BookmarkBlock
@@ -723,6 +754,10 @@ Block = Annotated[
         | ToDoBlock
         | ToggleBlock
         | VideoBlock
+        | SyncedBlockBlock
+        | LinkPreviewBlock
+        | LinkToPageBlock
+        | UnsupportedBlock
     ),
     Field(discriminator="type"),
 ]
@@ -743,7 +778,7 @@ class BlockChildrenResponse(BaseModel):
     request_id: str
 
 
-BlockCreatePayload = Annotated[
+type BlockCreatePayload = Annotated[
     (
         CreateAudioBlock
         | CreateBookmarkBlock
@@ -773,6 +808,8 @@ BlockCreatePayload = Annotated[
         | CreateToDoBlock
         | CreateToggleBlock
         | CreateVideoBlock
+        | CreateSyncedBlockBlock
+        | CreateLinkToPageBlock
     ),
     Field(discriminator="type"),
 ]
