@@ -1,8 +1,8 @@
 from pydantic import BaseModel
 
-from notionary.blocks.rich_text.models import RichText
-from notionary.data_source.properties.schemas import DiscriminatedDataSourceProperty
+from notionary.data_source.properties.schemas import AnyDataSourceProperty
 from notionary.page.schemas import NotionPageDto
+from notionary.rich_text.schemas import RichText
 from notionary.shared.entity.schemas import EntityResponseDto, NotionEntityUpdateDto
 from notionary.shared.models.parent import Parent
 
@@ -24,4 +24,4 @@ class DataSourceDto(EntityResponseDto):
     title: list[RichText]
     description: list[RichText]
     archived: bool
-    properties: dict[str, DiscriminatedDataSourceProperty]
+    properties: dict[str, AnyDataSourceProperty]
