@@ -1,12 +1,13 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import AsyncIterator, Callable
+from collections.abc import AsyncIterator
 from typing import TYPE_CHECKING, Self
 
-from notionary.blocks.rich_text.rich_text_markdown_converter import RichTextToMarkdownConverter
 from notionary.data_source.http.client import DataSourceClient
-from notionary.data_source.http.data_source_instance_client import DataSourceInstanceClient
+from notionary.data_source.http.data_source_instance_client import (
+    DataSourceInstanceClient,
+)
 from notionary.data_source.properties.schemas import (
     DataSourceMultiSelectProperty,
     DataSourceProperty,
@@ -16,18 +17,32 @@ from notionary.data_source.properties.schemas import (
     DataSourceSelectProperty,
     DataSourceStatusProperty,
 )
-from notionary.data_source.query import DataSourceQueryBuilder, DataSourceQueryParams, QueryResolver
+from notionary.data_source.query import (
+    DataSourceQueryBuilder,
+    DataSourceQueryParams,
+    QueryResolver,
+)
 from notionary.data_source.schema.service import DataSourcePropertySchemaFormatter
 from notionary.data_source.schemas import DataSourceDto
-from notionary.exceptions.data_source.properties import DataSourcePropertyNotFound, DataSourcePropertyTypeError
-from notionary.page.properties.models import PageTitleProperty
+from notionary.exceptions.data_source.properties import (
+    DataSourcePropertyNotFound,
+    DataSourcePropertyTypeError,
+)
+from notionary.file_upload.service import NotionFileUpload
+from notionary.page.properties.schemas import PageTitleProperty
 from notionary.page.schemas import NotionPageDto
+from notionary.rich_text.rich_text_to_markdown.converter import (
+    RichTextToMarkdownConverter,
+)
 from notionary.shared.entity.dto_parsers import (
     extract_description,
     extract_title,
 )
-from notionary.shared.entity.entity_metadata_update_client import EntityMetadataUpdateClient
+from notionary.shared.entity.entity_metadata_update_client import (
+    EntityMetadataUpdateClient,
+)
 from notionary.shared.entity.service import Entity
+from notionary.user.service import UserService
 from notionary.workspace.query.service import WorkspaceQueryService
 
 if TYPE_CHECKING:
@@ -43,8 +58,12 @@ class NotionDataSource(Entity):
         properties: dict[str, DataSourceProperty],
         data_source_instance_client: DataSourceInstanceClient,
         query_resolver: QueryResolver | None = None,
+        user_service: UserService | None = None,
+        file_upload_service: NotionFileUpload | None = None,
     ) -> None:
-        super().__init__(dto=dto)
+        super().__init__(
+            dto=dto, user_service=user_service, file_upload_service=file_upload_service
+        )
 
         self._parent_database: NotionDatabase | None = None
         self._title = title
@@ -116,6 +135,10 @@ class NotionDataSource(Entity):
     def properties(self) -> dict[str, DataSourceProperty]:
         return self._properties
 
+    @property
+    def data_source_query_builder(self) -> DataSourceQueryBuilder:
+        return DataSourceQueryBuilder(properties=self._properties)
+
     async def create_blank_page(self, title: str | None = None) -> NotionPage:
         return await self._data_source_client.create_blank_page(title=title)
 
@@ -138,7 +161,9 @@ class NotionDataSource(Entity):
         self._archived = False
 
     async def update_description(self, description: str) -> None:
-        self._description = await self._data_source_client.update_description(description)
+        self._description = await self._data_source_client.update_description(
+            description
+        )
 
     async def get_options_for_property_by_name(self, property_name: str) -> list[str]:
         prop = self._properties.get(property_name)
@@ -161,22 +186,36 @@ class NotionDataSource(Entity):
         return []
 
     def get_select_options_by_property_name(self, property_name: str) -> list[str]:
-        select_prop = self._get_typed_property_or_raise(property_name, DataSourceSelectProperty)
+        select_prop = self._get_typed_property_or_raise(
+            property_name, DataSourceSelectProperty
+        )
         return select_prop.option_names
 
-    def get_multi_select_options_by_property_name(self, property_name: str) -> list[DataSourcePropertyOption]:
-        multi_select_prop = self._get_typed_property_or_raise(property_name, DataSourceMultiSelectProperty)
+    def get_multi_select_options_by_property_name(
+        self, property_name: str
+    ) -> list[DataSourcePropertyOption]:
+        multi_select_prop = self._get_typed_property_or_raise(
+            property_name, DataSourceMultiSelectProperty
+        )
         return multi_select_prop.option_names
 
     def get_status_options_by_property_name(self, property_name: str) -> list[str]:
-        status_prop = self._get_typed_property_or_raise(property_name, DataSourceStatusProperty)
+        status_prop = self._get_typed_property_or_raise(
+            property_name, DataSourceStatusProperty
+        )
         return status_prop.option_names
 
-    async def get_relation_options_by_property_name(self, property_name: str) -> list[str]:
-        relation_prop = self._get_typed_property_or_raise(property_name, DataSourceRelationProperty)
+    async def get_relation_options_by_property_name(
+        self, property_name: str
+    ) -> list[str]:
+        relation_prop = self._get_typed_property_or_raise(
+            property_name, DataSourceRelationProperty
+        )
         return await self._get_relation_options(relation_prop)
 
-    async def _get_relation_options(self, relation_prop: DataSourceRelationProperty) -> list[str]:
+    async def _get_relation_options(
+        self, relation_prop: DataSourceRelationProperty
+    ) -> list[str]:
         related_data_source_id = relation_prop.related_data_source_id
         if not related_data_source_id:
             return []
@@ -197,7 +236,11 @@ class NotionDataSource(Entity):
             return None
 
         title_property = next(
-            (prop for prop in page.properties.values() if isinstance(prop, PageTitleProperty)),
+            (
+                prop
+                for prop in page.properties.values()
+                if isinstance(prop, PageTitleProperty)
+            ),
             None,
         )
 
@@ -206,7 +249,9 @@ class NotionDataSource(Entity):
 
         return "".join(item.plain_text for item in title_property.title)
 
-    def _get_typed_property_or_raise(self, name: str, property_type: type[DataSourcePropertyT]) -> DataSourcePropertyT:
+    def _get_typed_property_or_raise(
+        self, name: str, property_type: type[DataSourcePropertyT]
+    ) -> DataSourcePropertyT:
         prop = self._properties.get(name)
 
         if prop is None:
@@ -217,33 +262,16 @@ class NotionDataSource(Entity):
 
         if not isinstance(prop, property_type):
             raise DataSourcePropertyTypeError(
-                property_name=name, expected_type=property_type.__name__, actual_type=type(prop).__name__
+                property_name=name,
+                expected_type=property_type.__name__,
+                actual_type=type(prop).__name__,
             )
 
         return prop
 
-    def filter(self) -> DataSourceQueryBuilder:
+    def get_query_builder(self) -> DataSourceQueryBuilder:
         return DataSourceQueryBuilder(properties=self._properties)
 
-    async def query_pages(
-        self, filter_fn: Callable[[DataSourceQueryBuilder], DataSourceQueryBuilder]
-    ) -> list[NotionPage]:
-        builder = DataSourceQueryBuilder(properties=self._properties)
-        configured_builder = filter_fn(builder)
-        query_params = configured_builder.build()
-
-        return await self.get_pages(query_params)
-
-    async def query_pages_stream(
-        self, filter_fn: Callable[[DataSourceQueryBuilder], DataSourceQueryBuilder]
-    ) -> AsyncIterator[NotionPage]:
-        builder = DataSourceQueryBuilder(properties=self._properties)
-        configured_builder = filter_fn(builder)
-        query_params = configured_builder.build()
-
-        async for page in self.get_pages_stream(query_params):
-            yield page
-
     async def get_pages(
         self,
         query_params: DataSourceQueryParams | None = None,
@@ -251,10 +279,12 @@ class NotionDataSource(Entity):
         from notionary import NotionPage
 
         resolved_params = await self._resolve_query_params_if_needed(query_params)
-        query_response = await self._data_source_client.query(query_params=resolved_params)
+        query_response = await self._data_source_client.query(
+            query_params=resolved_params
+        )
         return [await NotionPage.from_id(page.id) for page in query_response.results]
 
-    async def get_pages_stream(
+    async def iter_pages(
         self,
         query_params: DataSourceQueryParams | None = None,
     ) -> AsyncIterator[NotionPage]:
@@ -262,7 +292,9 @@ class NotionDataSource(Entity):
 
         resolved_params = await self._resolve_query_params_if_needed(query_params)
 
-        async for page in self._data_source_client.query_stream(query_params=resolved_params):
+        async for page in self._data_source_client.query_stream(
+            query_params=resolved_params
+        ):
             yield await NotionPage.from_id(page.id)
 
     async def _resolve_query_params_if_needed(
@@ -275,5 +307,11 @@ class NotionDataSource(Entity):
         return await self.query_resolver.resolve_params(query_params)
 
     async def get_schema_description(self) -> str:
-        formatter = DataSourcePropertySchemaFormatter(relation_options_fetcher=self._get_relation_options)
-        return await formatter.format(title=self._title, description=self._description, properties=self._properties)
+        formatter = DataSourcePropertySchemaFormatter(
+            relation_options_fetcher=self._get_relation_options
+        )
+        return await formatter.format(
+            title=self._title,
+            description=self._description,
+            properties=self._properties,
+        )
