@@ -1,14 +1,16 @@
-from __future__ import annotations
-
 import asyncio
 from collections.abc import Awaitable, Callable
 from typing import Self
 
-from notionary.blocks.rich_text.rich_text_markdown_converter import RichTextToMarkdownConverter
 from notionary.data_source.service import NotionDataSource
 from notionary.database.client import NotionDatabaseHttpClient
-from notionary.database.database_metadata_update_client import DatabaseMetadataUpdateClient
+from notionary.database.database_metadata_update_client import (
+    DatabaseMetadataUpdateClient,
+)
 from notionary.database.schemas import NotionDatabaseDto
+from notionary.rich_text.rich_text_to_markdown.converter import (
+    RichTextToMarkdownConverter,
+)
 from notionary.shared.entity.dto_parsers import (
     extract_description,
     extract_title,
@@ -16,7 +18,7 @@ from notionary.shared.entity.dto_parsers import (
 from notionary.shared.entity.service import Entity
 from notionary.workspace.query.service import WorkspaceQueryService
 
-type DataSourceFactory = Callable[[str], Awaitable[NotionDataSource]]
+type _DataSourceFactory = Callable[[str], Awaitable[NotionDataSource]]
 
 
 class NotionDatabase(Entity):
@@ -73,7 +75,8 @@ class NotionDatabase(Entity):
         client: NotionDatabaseHttpClient,
     ) -> Self:
         title, description = await asyncio.gather(
-            extract_title(dto, rich_text_converter), extract_description(dto, rich_text_converter)
+            extract_title(dto, rich_text_converter),
+            extract_description(dto, rich_text_converter),
         )
 
         metadata_update_client = DatabaseMetadataUpdateClient(database_id=dto.id)
@@ -104,7 +107,7 @@ class NotionDatabase(Entity):
 
     async def get_data_sources(
         self,
-        data_source_factory: DataSourceFactory = NotionDataSource.from_id,
+        data_source_factory: _DataSourceFactory = NotionDataSource.from_id,
     ) -> list[NotionDataSource]:
         if self._data_sources is None:
             self._data_sources = await self._load_data_sources(data_source_factory)
@@ -112,7 +115,7 @@ class NotionDatabase(Entity):
 
     async def _load_data_sources(
         self,
-        data_source_factory: DataSourceFactory,
+        data_source_factory: _DataSourceFactory,
     ) -> list[NotionDataSource]:
         tasks = [data_source_factory(ds_id) for ds_id in self._data_source_ids]
         return list(await asyncio.gather(*tasks))
@@ -122,5 +125,7 @@ class NotionDatabase(Entity):
         self._title = result.title[0].plain_text if result.title else ""
 
     async def set_description(self, description: str) -> None:
-        updated_description = await self.client.update_database_description(description=description)
+        updated_description = await self.client.update_database_description(
+            description=description
+        )
         self._description = updated_description
