@@ -7,10 +7,23 @@ from .api import (
     NotionServerError,
     NotionValidationError,
 )
-from .base import NotionaryError
-from .block_parsing import InsufficientColumnsError, InvalidColumnRatioSumError, UnsupportedVideoFormatError
+from .base import NotionaryException
+from .block_parsing import (
+    InsufficientColumnsError,
+    InvalidColumnRatioSumError,
+    UnsupportedVideoFormatError,
+)
 from .data_source import DataSourcePropertyNotFound, DataSourcePropertyTypeError
-from .properties import AccessPagePropertyWithoutDataSourceError, PagePropertyNotFoundError, PagePropertyTypeError
+from .file_upload import (
+    FileSizeException,
+    NoFileExtensionException,
+    UnsupportedFileTypeException,
+)
+from .properties import (
+    AccessPagePropertyWithoutDataSourceError,
+    PagePropertyNotFoundError,
+    PagePropertyTypeError,
+)
 from .search import DatabaseNotFound, DataSourceNotFound, EntityNotFound, PageNotFound
 
 __all__ = [
@@ -20,8 +33,10 @@ __all__ = [
     "DataSourcePropertyTypeError",
     "DatabaseNotFound",
     "EntityNotFound",
+    "FileSizeException",
     "InsufficientColumnsError",
     "InvalidColumnRatioSumError",
+    "NoFileExtensionException",
     "NotionApiError",
     "NotionAuthenticationError",
     "NotionConnectionError",
@@ -29,9 +44,10 @@ __all__ = [
     "NotionResourceNotFoundError",
     "NotionServerError",
     "NotionValidationError",
-    "NotionaryError",
+    "NotionaryException",
     "PageNotFound",
     "PagePropertyNotFoundError",
     "PagePropertyTypeError",
+    "UnsupportedFileTypeException",
     "UnsupportedVideoFormatError",
 ]
