@@ -1,9 +1,9 @@
 import difflib
 
-from notionary.exceptions.base import NotionaryError
+from notionary.exceptions.base import NotionaryException
 
 
-class DataSourcePropertyNotFound(NotionaryError):
+class DataSourcePropertyNotFound(NotionaryException):
     def __init__(
         self,
         property_name: str,
@@ -28,7 +28,9 @@ class DataSourcePropertyNotFound(NotionaryError):
         super().__init__(message)
 
 
-class DataSourcePropertyTypeError(NotionaryError):
-    def __init__(self, property_name: str, expected_type: str, actual_type: str) -> None:
+class DataSourcePropertyTypeError(NotionaryException):
+    def __init__(
+        self, property_name: str, expected_type: str, actual_type: str
+    ) -> None:
         message = f"Property '{property_name}' has the wrong type. Expected: '{expected_type}', found: '{actual_type}'."
         super().__init__(message)
