@@ -18,7 +18,7 @@ from notionary.http.models import HttpMethod
 from notionary.shared.typings import JsonDict
 from notionary.utils.mixins.logging import LoggingMixin
 
-load_dotenv()
+load_dotenv(override=True)
 
 
 class NotionHttpClient(LoggingMixin):
@@ -44,34 +44,32 @@ class NotionHttpClient(LoggingMixin):
         self._is_initialized = False
 
     def __del__(self):
-        """Auto-cleanup when client is destroyed."""
         if not hasattr(self, "client") or not self.client:
             return
 
         try:
             loop = asyncio.get_event_loop()
             if not loop.is_running():
-                self.logger.warning("Event loop not running, could not auto-close NotionHttpClient")
+                self.logger.warning(
+                    "Event loop not running, could not auto-close NotionHttpClient"
+                )
                 return
 
             loop.create_task(self.close())
             self.logger.debug("Created cleanup task for NotionHttpClient")
         except RuntimeError:
-            self.logger.warning("No event loop available for auto-closing NotionHttpClient")
+            self.logger.warning(
+                "No event loop available for auto-closing NotionHttpClient"
+            )
 
     async def __aenter__(self):
-        """Async context manager entry."""
         await self._ensure_initialized()
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        """Async context manager exit."""
         await self.close()
 
     async def close(self) -> None:
-        """
-        Closes the HTTP client and releases resources.
-        """
         if not hasattr(self, "client") or not self.client:
             return
 
@@ -80,34 +78,31 @@ class NotionHttpClient(LoggingMixin):
         self._is_initialized = False
         self.logger.debug("NotionHttpClient closed")
 
-    async def get(self, endpoint: str, params: JsonDict | None = None) -> JsonDict | None:
-        return await self.make_request(HttpMethod.GET, endpoint, params=params)
+    async def get(
+        self, endpoint: str, params: JsonDict | None = None
+    ) -> JsonDict | None:
+        return await self._make_request(HttpMethod.GET, endpoint, params=params)
 
-    async def post(self, endpoint: str, data: JsonDict | None = None) -> JsonDict | None:
-        return await self.make_request(HttpMethod.POST, endpoint, data)
+    async def post(
+        self, endpoint: str, data: JsonDict | None = None
+    ) -> JsonDict | None:
+        return await self._make_request(HttpMethod.POST, endpoint, data)
 
-    async def patch(self, endpoint: str, data: JsonDict | None = None) -> JsonDict | None:
-        return await self.make_request(HttpMethod.PATCH, endpoint, data)
+    async def patch(
+        self, endpoint: str, data: JsonDict | None = None
+    ) -> JsonDict | None:
+        return await self._make_request(HttpMethod.PATCH, endpoint, data)
 
     async def delete(self, endpoint: str) -> JsonDict | None:
-        return await self.make_request(HttpMethod.DELETE, endpoint)
+        return await self._make_request(HttpMethod.DELETE, endpoint)
 
-    async def make_request(
+    async def _make_request(
         self,
         method: HttpMethod,
         endpoint: str,
         data: JsonDict | None = None,
         params: JsonDict | None = None,
     ) -> JsonDict | None:
-        """
-        Executes an HTTP request and returns the data or None on error.
-
-        Args:
-            method: HTTP method to use
-            endpoint: API endpoint
-            data: Request body data (for POST/PATCH)
-            params: Query parameters (for GET requests)
-        """
         await self._ensure_initialized()
 
         url = f"{self.BASE_URL}/{endpoint.lstrip('/')}"
@@ -120,10 +115,15 @@ class NotionHttpClient(LoggingMixin):
             if params:
                 request_kwargs["params"] = params
 
-            if method.value in [HttpMethod.POST.value, HttpMethod.PATCH.value] and data is not None:
+            if (
+                method.value in [HttpMethod.POST.value, HttpMethod.PATCH.value]
+                and data is not None
+            ):
                 request_kwargs["json"] = data
 
-            response: httpx.Response = await getattr(self.client, method.value)(url, **request_kwargs)
+            response: httpx.Response = await getattr(self.client, method.value)(
+                url, **request_kwargs
+            )
 
             response.raise_for_status()
             result_data = response.json()
@@ -141,7 +141,6 @@ class NotionHttpClient(LoggingMixin):
         status_code = e.response.status_code
         response_text = e.response.text
 
-        # Map HTTP status codes to specific business exceptions
         if status_code == 401:
             raise NotionAuthenticationError(
                 "Invalid or missing API key. Please check your Notion integration token.",
@@ -189,7 +188,11 @@ class NotionHttpClient(LoggingMixin):
 
     def _find_token(self) -> str | None:
         token = next(
-            (os.getenv(var) for var in ("NOTION_SECRET", "NOTION_INTEGRATION_KEY", "NOTION_TOKEN") if os.getenv(var)),
+            (
+                os.getenv(var)
+                for var in ("NOTION_SECRET", "NOTION_INTEGRATION_KEY", "NOTION_TOKEN")
+                if os.getenv(var)
+            ),
             None,
         )
         if token:
