@@ -2,12 +2,12 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.parser.context import BlockParsingContext
-from notionary.page.content.syntax import SyntaxRegistry
 
 
 class LineParser(ABC):
-    def __init__(self, syntax_registry: SyntaxRegistry | None = None) -> None:
+    def __init__(self, syntax_registry: SyntaxDefinitionRegistry | None = None) -> None:
         self._next_handler: LineParser | None = None
         self._syntax_registry = syntax_registry
 
