@@ -1,18 +1,25 @@
 from typing import override
 
-from notionary.blocks.rich_text.markdown_rich_text_converter import (
-    MarkdownRichTextConverter,
+from notionary.blocks.schemas import (
+    CreateBulletedListItemBlock,
+    CreateBulletedListItemData,
 )
-from notionary.blocks.schemas import CreateBulletedListItemBlock, CreateBulletedListItemData
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.parser.parsers.base import (
     BlockParsingContext,
     LineParser,
 )
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.markdown_to_rich_text.converter import (
+    MarkdownRichTextConverter,
+)
 
 
 class BulletedListParser(LineParser):
-    def __init__(self, syntax_registry: SyntaxRegistry, rich_text_converter: MarkdownRichTextConverter) -> None:
+    def __init__(
+        self,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_converter: MarkdownRichTextConverter,
+    ) -> None:
         super().__init__(syntax_registry)
         self._syntax = syntax_registry.get_bulleted_list_syntax()
         self._rich_text_converter = rich_text_converter
@@ -35,7 +42,9 @@ class BulletedListParser(LineParser):
         await self._process_nested_children(block, context)
         context.result_blocks.append(block)
 
-    async def _process_nested_children(self, block: CreateBulletedListItemBlock, context: BlockParsingContext) -> None:
+    async def _process_nested_children(
+        self, block: CreateBulletedListItemBlock, context: BlockParsingContext
+    ) -> None:
         child_lines = self._collect_child_lines(context)
         if not child_lines:
             return
@@ -57,13 +66,17 @@ class BulletedListParser(LineParser):
         children_text = self._convert_lines_to_text(stripped_lines)
         return await context.parse_nested_markdown(children_text)
 
-    def _remove_parent_indentation(self, lines: list[str], context: BlockParsingContext) -> list[str]:
+    def _remove_parent_indentation(
+        self, lines: list[str], context: BlockParsingContext
+    ) -> list[str]:
         return context.strip_indentation_level(lines, levels=1)
 
     def _convert_lines_to_text(self, lines: list[str]) -> str:
         return "\n".join(lines)
 
-    async def _create_bulleted_list_block(self, text: str) -> CreateBulletedListItemBlock | None:
+    async def _create_bulleted_list_block(
+        self, text: str
+    ) -> CreateBulletedListItemBlock | None:
         content = self._extract_list_content(text)
         if content is None:
             return None
