@@ -1,18 +1,22 @@
 from typing import override
 
-from notionary.blocks.rich_text.markdown_rich_text_converter import (
-    MarkdownRichTextConverter,
-)
 from notionary.blocks.schemas import BlockCreatePayload
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.parser.parsers.base import (
     BlockParsingContext,
     LineParser,
 )
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.markdown_to_rich_text.converter import (
+    MarkdownRichTextConverter,
+)
 
 
 class CaptionParser(LineParser):
-    def __init__(self, syntax_registry: SyntaxRegistry, rich_text_converter: MarkdownRichTextConverter) -> None:
+    def __init__(
+        self,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_converter: MarkdownRichTextConverter,
+    ) -> None:
         super().__init__(syntax_registry)
         self._syntax = syntax_registry.get_caption_syntax()
         self._rich_text_converter = rich_text_converter
@@ -49,7 +53,9 @@ class CaptionParser(LineParser):
             return False
         return hasattr(block_data, "caption")
 
-    def _attach_caption_to_block(self, block: BlockCreatePayload, caption_rich_text: list) -> None:
+    def _attach_caption_to_block(
+        self, block: BlockCreatePayload, caption_rich_text: list
+    ) -> None:
         block_data = getattr(block, block.type.value)
         if hasattr(block_data, "caption"):
             block_data.caption = caption_rich_text
