@@ -1,22 +1,26 @@
 from typing import override
 
-from notionary.blocks.rich_text.markdown_rich_text_converter import (
-    MarkdownRichTextConverter,
-)
 from notionary.blocks.schemas import (
     BlockColor,
     CreateNumberedListItemBlock,
     CreateNumberedListItemData,
 )
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.parser.parsers.base import (
     BlockParsingContext,
     LineParser,
 )
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.markdown_to_rich_text.converter import (
+    MarkdownRichTextConverter,
+)
 
 
 class NumberedListParser(LineParser):
-    def __init__(self, syntax_registry: SyntaxRegistry, rich_text_converter: MarkdownRichTextConverter) -> None:
+    def __init__(
+        self,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_converter: MarkdownRichTextConverter,
+    ) -> None:
         super().__init__(syntax_registry)
         self._syntax = syntax_registry.get_numbered_list_syntax()
         self._rich_text_converter = rich_text_converter
@@ -39,7 +43,9 @@ class NumberedListParser(LineParser):
         await self._process_nested_children(block, context)
         context.result_blocks.append(block)
 
-    async def _process_nested_children(self, block: CreateNumberedListItemBlock, context: BlockParsingContext) -> None:
+    async def _process_nested_children(
+        self, block: CreateNumberedListItemBlock, context: BlockParsingContext
+    ) -> None:
         child_lines = self._collect_child_lines(context)
         if not child_lines:
             return
@@ -61,13 +67,17 @@ class NumberedListParser(LineParser):
         children_text = self._convert_lines_to_text(stripped_lines)
         return await context.parse_nested_markdown(children_text)
 
-    def _remove_parent_indentation(self, lines: list[str], context: BlockParsingContext) -> list[str]:
+    def _remove_parent_indentation(
+        self, lines: list[str], context: BlockParsingContext
+    ) -> list[str]:
         return context.strip_indentation_level(lines, levels=1)
 
     def _convert_lines_to_text(self, lines: list[str]) -> str:
         return "\n".join(lines)
 
-    async def _create_numbered_list_block(self, text: str) -> CreateNumberedListItemBlock | None:
+    async def _create_numbered_list_block(
+        self, text: str
+    ) -> CreateNumberedListItemBlock | None:
         content = self._extract_list_content(text)
         if content is None:
             return None
@@ -85,5 +95,7 @@ class NumberedListParser(LineParser):
         return await self._rich_text_converter.to_rich_text(content)
 
     def _build_block(self, rich_text) -> CreateNumberedListItemBlock:
-        numbered_list_content = CreateNumberedListItemData(rich_text=rich_text, color=BlockColor.DEFAULT)
+        numbered_list_content = CreateNumberedListItemData(
+            rich_text=rich_text, color=BlockColor.DEFAULT
+        )
         return CreateNumberedListItemBlock(numbered_list_item=numbered_list_content)
