@@ -1,14 +1,14 @@
 from typing import override
 
 from notionary.blocks.enums import BlockColor
-from notionary.blocks.rich_text.markdown_rich_text_converter import (
-    MarkdownRichTextConverter,
-)
 from notionary.blocks.schemas import CreateParagraphBlock, CreateParagraphData
 from notionary.page.content.parser.parsers.base import (
     BlockParsingContext,
     LineParser,
 )
+from notionary.rich_text.markdown_to_rich_text.converter import (
+    MarkdownRichTextConverter,
+)
 
 
 class ParagraphParser(LineParser):
@@ -33,5 +33,7 @@ class ParagraphParser(LineParser):
             return None
 
         rich_text = await self._rich_text_converter.to_rich_text(text)
-        paragraph_content = CreateParagraphData(rich_text=rich_text, color=BlockColor.DEFAULT)
+        paragraph_content = CreateParagraphData(
+            rich_text=rich_text, color=BlockColor.DEFAULT
+        )
         return CreateParagraphBlock(paragraph=paragraph_content)
