@@ -1,7 +1,7 @@
 from collections.abc import Awaitable, Callable
 
 from notionary.blocks.schemas import Block
-from notionary.page.content.syntax.grammar import MarkdownGrammar
+from notionary.markdown.syntax.definition.grammar import MarkdownGrammar
 
 ConvertChildrenCallback = Callable[[list[Block], int], Awaitable[str]]
 
@@ -25,14 +25,20 @@ class MarkdownRenderingContext:
     async def render_children(self) -> str:
         return await self._convert_children_to_markdown(self.indent_level)
 
-    async def render_children_with_additional_indent(self, additional_indent: int) -> str:
-        return await self._convert_children_to_markdown(self.indent_level + additional_indent)
+    async def render_children_with_additional_indent(
+        self, additional_indent: int
+    ) -> str:
+        return await self._convert_children_to_markdown(
+            self.indent_level + additional_indent
+        )
 
     async def _convert_children_to_markdown(self, indent_level: int) -> str:
         if not self._has_children() or not self.convert_children_callback:
             return ""
 
-        return await self.convert_children_callback(self._get_children_blocks(), indent_level)
+        return await self.convert_children_callback(
+            self._get_children_blocks(), indent_level
+        )
 
     def _get_children_blocks(self) -> list[Block]:
         if self._has_children():
@@ -40,7 +46,11 @@ class MarkdownRenderingContext:
         return []
 
     def _has_children(self) -> bool:
-        return self.block.has_children and self.block.children and len(self.block.children) > 0
+        return (
+            self.block.has_children
+            and self.block.children
+            and len(self.block.children) > 0
+        )
 
     def indent_text(self, text: str) -> str:
         if not text:
