@@ -3,13 +3,13 @@ from __future__ import annotations
 from abc import ABC, abstractmethod
 
 from notionary.blocks.schemas import Block
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.renderer.context import MarkdownRenderingContext
-from notionary.page.content.syntax import SyntaxRegistry
 
 
 class BlockRenderer(ABC):
-    def __init__(self, syntax_registry: SyntaxRegistry | None = None) -> None:
-        self._syntax_registry = syntax_registry or SyntaxRegistry()
+    def __init__(self, syntax_registry: SyntaxDefinitionRegistry) -> None:
+        self._syntax_registry = syntax_registry
         self._next_handler: BlockRenderer | None = None
 
     def set_next(self, handler: BlockRenderer) -> BlockRenderer:
