@@ -1,21 +1,23 @@
 from abc import abstractmethod
 from typing import override
 
-from notionary.blocks.rich_text.rich_text_markdown_converter import RichTextToMarkdownConverter
 from notionary.blocks.schemas import Block
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.renderer.context import MarkdownRenderingContext
 from notionary.page.content.renderer.renderers.base import BlockRenderer
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.rich_text_to_markdown.converter import (
+    RichTextToMarkdownConverter,
+)
 
 
 class CaptionedBlockRenderer(BlockRenderer):
     def __init__(
         self,
-        syntax_registry: SyntaxRegistry | None = None,
-        rich_text_markdown_converter: RichTextToMarkdownConverter | None = None,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_markdown_converter: RichTextToMarkdownConverter,
     ) -> None:
         super().__init__(syntax_registry=syntax_registry)
-        self._rich_text_markdown_converter = rich_text_markdown_converter or RichTextToMarkdownConverter()
+        self._rich_text_markdown_converter = rich_text_markdown_converter
 
     @abstractmethod
     async def _render_main_content(self, block: Block) -> str:
@@ -53,6 +55,8 @@ class CaptionedBlockRenderer(BlockRenderer):
         if not caption_rich_text:
             return ""
 
-        caption_markdown = await self._rich_text_markdown_converter.to_markdown(caption_rich_text)
+        caption_markdown = await self._rich_text_markdown_converter.to_markdown(
+            caption_rich_text
+        )
 
         return f"\n[caption] {caption_markdown}"
