@@ -42,7 +42,9 @@ class ColumnRenderer(BlockRenderer):
 
         return delimiter
 
-    async def _render_children_with_indentation(self, context: MarkdownRenderingContext) -> str:
+    async def _render_children_with_indentation(
+        self, context: MarkdownRenderingContext
+    ) -> str:
         original_indent = context.indent_level
         context.indent_level += 1
 
