@@ -19,7 +19,9 @@ class EquationRenderer(BlockRenderer):
             return
 
         syntax = self._syntax_registry.get_equation_syntax()
-        equation_markdown = f"{syntax.start_delimiter}{expression}{syntax.end_delimiter}"
+        equation_markdown = (
+            f"{syntax.start_delimiter}{expression}{syntax.end_delimiter}"
+        )
 
         if context.indent_level > 0:
             equation_markdown = context.indent_text(equation_markdown)
