@@ -1,12 +1,16 @@
 from typing import override
 
 from notionary.blocks.schemas import Block
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.renderer.context import MarkdownRenderingContext
 from notionary.page.content.renderer.renderers.base import BlockRenderer
 from notionary.utils.mixins.logging import LoggingMixin
 
 
 class FallbackRenderer(BlockRenderer, LoggingMixin):
+    def __init__(self, syntax_registry: SyntaxDefinitionRegistry) -> None:
+        super().__init__(syntax_registry=syntax_registry)
+
     @override
     def _can_handle(self, block: Block) -> bool:
         return True
