@@ -1,20 +1,22 @@
 from typing import override
 
-from notionary.blocks.rich_text.rich_text_markdown_converter import RichTextToMarkdownConverter
 from notionary.blocks.schemas import Block, BlockType
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.renderer.context import MarkdownRenderingContext
 from notionary.page.content.renderer.renderers.base import BlockRenderer
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.rich_text_to_markdown.converter import (
+    RichTextToMarkdownConverter,
+)
 
 
 class QuoteRenderer(BlockRenderer):
     def __init__(
         self,
-        syntax_registry: SyntaxRegistry | None = None,
-        rich_text_markdown_converter: RichTextToMarkdownConverter | None = None,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_markdown_converter: RichTextToMarkdownConverter,
     ) -> None:
         super().__init__(syntax_registry=syntax_registry)
-        self._rich_text_markdown_converter = rich_text_markdown_converter or RichTextToMarkdownConverter()
+        self._rich_text_markdown_converter = rich_text_markdown_converter
 
     @override
     def _can_handle(self, block: Block) -> bool:
@@ -30,7 +32,9 @@ class QuoteRenderer(BlockRenderer):
 
         syntax = self._syntax_registry.get_quote_syntax()
         quote_lines = markdown.split("\n")
-        quote_markdown = "\n".join(f"{syntax.start_delimiter}{line}" for line in quote_lines)
+        quote_markdown = "\n".join(
+            f"{syntax.start_delimiter}{line}" for line in quote_lines
+        )
 
         if context.indent_level > 0:
             quote_markdown = context.indent_text(quote_markdown)
@@ -46,4 +50,6 @@ class QuoteRenderer(BlockRenderer):
         if not block.quote or not block.quote.rich_text:
             return None
 
-        return await self._rich_text_markdown_converter.to_markdown(block.quote.rich_text)
+        return await self._rich_text_markdown_converter.to_markdown(
+            block.quote.rich_text
+        )
