@@ -1,21 +1,23 @@
 from typing import override
 
 from notionary.blocks.enums import BlockType
-from notionary.blocks.rich_text.rich_text_markdown_converter import RichTextToMarkdownConverter
 from notionary.blocks.schemas import Block
+from notionary.markdown.syntax.definition.registry import SyntaxDefinitionRegistry
 from notionary.page.content.renderer.context import MarkdownRenderingContext
 from notionary.page.content.renderer.renderers.base import BlockRenderer
-from notionary.page.content.syntax import SyntaxRegistry
+from notionary.rich_text.rich_text_to_markdown.converter import (
+    RichTextToMarkdownConverter,
+)
 
 
 class ToggleRenderer(BlockRenderer):
     def __init__(
         self,
-        syntax_registry: SyntaxRegistry | None = None,
-        rich_text_markdown_converter: RichTextToMarkdownConverter | None = None,
+        syntax_registry: SyntaxDefinitionRegistry,
+        rich_text_markdown_converter: RichTextToMarkdownConverter,
     ) -> None:
         super().__init__(syntax_registry=syntax_registry)
-        self._rich_text_markdown_converter = rich_text_markdown_converter or RichTextToMarkdownConverter()
+        self._rich_text_markdown_converter = rich_text_markdown_converter
 
     @override
     def _can_handle(self, block: Block) -> bool:
