@@ -1,19 +1,21 @@
-from collections.abc import Callable
 from typing import Self
 
 from notionary.blocks.client import NotionBlockHttpClient
-from notionary.blocks.rich_text.rich_text_markdown_converter import convert_rich_text_to_markdown
+from notionary.blocks.content import BlockContentService, create_block_content_service
+from notionary.blocks.service import NotionBlock
 from notionary.comments.models import Comment
 from notionary.comments.service import CommentService
-from notionary.page.content.factory import PageContentServiceFactory
-from notionary.page.content.markdown.builder import MarkdownBuilder
-from notionary.page.content.service import PageContentService
+from notionary.markdown.builder import MarkdownBuilder
 from notionary.page.page_http_client import NotionPageHttpClient
 from notionary.page.page_metadata_update_client import PageMetadataUpdateClient
 from notionary.page.properties.factory import PagePropertyHandlerFactory
-from notionary.page.properties.models import PageTitleProperty
+from notionary.page.properties.schemas import PageTitleProperty
 from notionary.page.properties.service import PagePropertyHandler
 from notionary.page.schemas import NotionPageDto
+from notionary.rich_text.rich_text_to_markdown import (
+    RichTextToMarkdownConverter,
+    create_rich_text_to_markdown_converter,
+)
 from notionary.shared.entity.service import Entity
 from notionary.workspace.query.service import WorkspaceQueryService
 
@@ -26,8 +28,9 @@ class NotionPage(Entity):
         page_property_handler: PagePropertyHandler,
         block_client: NotionBlockHttpClient,
         comment_service: CommentService,
-        page_content_service: PageContentService,
+        block_content_service: BlockContentService,
         metadata_update_client: PageMetadataUpdateClient,
+        rich_text_converter: RichTextToMarkdownConverter | None = None,
     ) -> None:
         super().__init__(dto=dto)
 
@@ -36,8 +39,9 @@ class NotionPage(Entity):
 
         self._block_client = block_client
         self._comment_service = comment_service
-        self._page_content_service = page_content_service
+        self._block_content_service = block_content_service
         self._metadata_update_client = metadata_update_client
+        self._rich_text_converter = rich_text_converter or RichTextToMarkdownConverter()
         self.properties = page_property_handler
 
     @classmethod
@@ -71,7 +75,9 @@ class NotionPage(Entity):
         page_property_handler_factory: PagePropertyHandlerFactory,
     ) -> Self:
         title_task = cls._extract_title_from_dto(dto)
-        page_property_handler = page_property_handler_factory.create_from_page_response(dto)
+        page_property_handler = page_property_handler_factory.create_from_page_response(
+            dto
+        )
 
         title = await title_task
 
@@ -91,10 +97,12 @@ class NotionPage(Entity):
         block_client = NotionBlockHttpClient()
         comment_service = CommentService()
 
-        page_content_service_factory = PageContentServiceFactory()
-        page_content_service = page_content_service_factory.create(page_id=dto.id, block_client=block_client)
+        block_content_service = create_block_content_service(
+            block_id=dto.id, block_client=block_client
+        )
 
         metadata_update_client = PageMetadataUpdateClient(page_id=dto.id)
+        rich_text_converter = create_rich_text_to_markdown_converter()
 
         return cls(
             dto=dto,
@@ -102,18 +110,24 @@ class NotionPage(Entity):
             page_property_handler=page_property_handler,
             block_client=block_client,
             comment_service=comment_service,
-            page_content_service=page_content_service,
+            block_content_service=block_content_service,
             metadata_update_client=metadata_update_client,
+            rich_text_converter=rich_text_converter,
         )
 
     @staticmethod
     async def _extract_title_from_dto(response: NotionPageDto) -> str:
         title_property = next(
-            (prop for prop in response.properties.values() if isinstance(prop, PageTitleProperty)),
+            (
+                prop
+                for prop in response.properties.values()
+                if isinstance(prop, PageTitleProperty)
+            ),
             None,
         )
         rich_text_title = title_property.title if title_property else []
-        return await convert_rich_text_to_markdown(rich_text_title)
+        converter = create_rich_text_to_markdown_converter()
+        return await converter.to_markdown(rich_text_title)
 
     @property
     def _entity_metadata_update_client(self) -> PageMetadataUpdateClient:
@@ -127,6 +141,9 @@ class NotionPage(Entity):
     def archived(self) -> bool:
         return self._archived
 
+    def create_markdown_builder(self) -> MarkdownBuilder:
+        return MarkdownBuilder()
+
     @property
     def markdown_builder() -> MarkdownBuilder:
         return MarkdownBuilder()
@@ -135,30 +152,32 @@ class NotionPage(Entity):
         return await self._comment_service.list_all_comments_for_page(page_id=self._id)
 
     async def post_top_level_comment(self, comment: str) -> None:
-        await self._comment_service.create_comment_on_page(page_id=self._id, text=comment)
+        await self._comment_service.create_comment_on_page(
+            page_id=self._id, text=comment
+        )
 
     async def post_reply_to_discussion(self, discussion_id: str, comment: str) -> None:
-        await self._comment_service.reply_to_discussion_by_id(discussion_id=discussion_id, text=comment)
+        await self._comment_service.reply_to_discussion_by_id(
+            discussion_id=discussion_id, text=comment
+        )
 
     async def set_title(self, title: str) -> None:
         await self.properties.set_title_property(title)
         self._title = title
 
-    async def append_markdown(
-        self,
-        content: (str | Callable[[MarkdownBuilder], MarkdownBuilder]),
-    ) -> None:
-        await self._page_content_service.append_markdown(content=content)
+    async def append_markdown(self, content: str) -> None:
+        await self._block_content_service.append_markdown(content=content)
 
-    async def replace_content(
-        self,
-        content: (str | Callable[[MarkdownBuilder], MarkdownBuilder]),
-    ) -> None:
-        await self._page_content_service.clear()
-        await self._page_content_service.append_markdown(content=content)
+    async def replace_content(self, content: str) -> None:
+        await self._block_content_service.clear()
+        await self._block_content_service.append_markdown(content=content)
 
     async def clear_page_content(self) -> None:
-        await self._page_content_service.clear()
+        await self._block_content_service.clear()
 
     async def get_markdown_content(self) -> str:
-        return await self._page_content_service.get_as_markdown()
+        return await self._block_content_service.get_children_as_markdown()
+
+    async def get_content_as_blocks(self) -> list[NotionBlock]:
+        blocks = await self._block_content_service.get_children_as_blocks()
+        return [NotionBlock.from_block(block) for block in blocks]
