@@ -3,27 +3,27 @@ from typing import Protocol
 
 from pydantic import BaseModel
 
-from notionary.blocks.rich_text.models import RichText
-from notionary.shared.models.cover import NotionCover
+from notionary.rich_text.schemas import RichText
+from notionary.shared.models.file import File
 from notionary.shared.models.icon import Icon
 from notionary.shared.models.parent import Parent
 from notionary.user.schemas import PartialUserDto
 
 
-class EntityWorkspaceQueryObjectType(StrEnum):
+class _EntityType(StrEnum):
     PAGE = "page"
     DATA_SOURCE = "data_source"
     DATABASE = "database"
 
 
 class EntityResponseDto(BaseModel):
-    object: EntityWorkspaceQueryObjectType
+    object: _EntityType
     id: str
     created_time: str
     created_by: PartialUserDto
     last_edited_time: str
     last_edited_by: PartialUserDto
-    cover: NotionCover | None = None
+    cover: File | None = None
     icon: Icon | None = None
     parent: Parent
     in_trash: bool
@@ -33,7 +33,7 @@ class EntityResponseDto(BaseModel):
 
 class NotionEntityUpdateDto(BaseModel):
     icon: Icon | None = None
-    cover: NotionCover | None = None
+    cover: File | None = None
     in_trash: bool | None = None
 
 
