@@ -4,7 +4,11 @@ import asyncio
 from collections.abc import AsyncIterator
 from typing import TYPE_CHECKING
 
-from notionary.exceptions.search import DatabaseNotFound, DataSourceNotFound, PageNotFound
+from notionary.exceptions.search import (
+    DatabaseNotFound,
+    DataSourceNotFound,
+    PageNotFound,
+)
 from notionary.utils.fuzzy import find_all_matches
 from notionary.workspace.client import WorkspaceClient
 from notionary.workspace.query.builder import NotionWorkspaceQueryConfigBuilder
@@ -18,7 +22,9 @@ class WorkspaceQueryService:
     def __init__(self, client: WorkspaceClient | None = None) -> None:
         self._client = client or WorkspaceClient()
 
-    async def get_pages_stream(self, search_config: WorkspaceQueryConfig) -> AsyncIterator[NotionPage]:
+    async def get_pages_stream(
+        self, search_config: WorkspaceQueryConfig
+    ) -> AsyncIterator[NotionPage]:
         from notionary import NotionPage
 
         async for page_dto in self._client.query_pages_stream(search_config):
@@ -27,21 +33,33 @@ class WorkspaceQueryService:
     async def get_pages(self, search_config: WorkspaceQueryConfig) -> list[NotionPage]:
         from notionary import NotionPage
 
-        page_dtos = [dto async for dto in self._client.query_pages_stream(search_config)]
+        page_dtos = [
+            dto async for dto in self._client.query_pages_stream(search_config)
+        ]
         page_tasks = [NotionPage.from_id(dto.id) for dto in page_dtos]
         return await asyncio.gather(*page_tasks)
 
-    async def get_data_sources_stream(self, search_config: WorkspaceQueryConfig) -> AsyncIterator[NotionDataSource]:
+    async def get_data_sources_stream(
+        self, search_config: WorkspaceQueryConfig
+    ) -> AsyncIterator[NotionDataSource]:
         from notionary import NotionDataSource
 
-        async for data_source_dto in self._client.query_data_sources_stream(search_config):
+        async for data_source_dto in self._client.query_data_sources_stream(
+            search_config
+        ):
             yield await NotionDataSource.from_id(data_source_dto.id)
 
-    async def get_data_sources(self, search_config: WorkspaceQueryConfig) -> list[NotionDataSource]:
+    async def get_data_sources(
+        self, search_config: WorkspaceQueryConfig
+    ) -> list[NotionDataSource]:
         from notionary import NotionDataSource
 
-        data_source_dtos = [dto async for dto in self._client.query_data_sources_stream(search_config)]
-        data_source_tasks = [NotionDataSource.from_id(dto.id) for dto in data_source_dtos]
+        data_source_dtos = [
+            dto async for dto in self._client.query_data_sources_stream(search_config)
+        ]
+        data_source_tasks = [
+            NotionDataSource.from_id(dto.id) for dto in data_source_dtos
+        ]
         return await asyncio.gather(*data_source_tasks)
 
     async def find_data_source(self, query: str) -> NotionDataSource:
@@ -76,13 +94,20 @@ class WorkspaceQueryService:
         )
         data_sources = await self.get_data_sources(config)
 
-        parent_database_ids = [data_sources.get_parent_database_id_if_present() for data_sources in data_sources]
+        parent_database_ids = [
+            data_sources.get_parent_database_id_if_present()
+            for data_sources in data_sources
+        ]
         # filter none values which should not happen but for safety
         parent_database_ids = [id for id in parent_database_ids if id is not None]
 
-        parent_database_tasks = [NotionDatabase.from_id(db_id) for db_id in parent_database_ids]
+        parent_database_tasks = [
+            NotionDatabase.from_id(db_id) for db_id in parent_database_ids
+        ]
         parent_databases = await asyncio.gather(*parent_database_tasks)
-        potential_databases = [database for database in parent_databases if database is not None]
+        potential_databases = [
+            database for database in parent_databases if database is not None
+        ]
 
         return self._find_exact_match(potential_databases, query, DatabaseNotFound)
 
@@ -96,7 +121,9 @@ class WorkspaceQueryService:
             raise exception_class(query, [])
 
         query_lower = query.lower()
-        exact_matches = [result for result in search_results if result.title.lower() == query_lower]
+        exact_matches = [
+            result for result in search_results if result.title.lower() == query_lower
+        ]
 
         if exact_matches:
             return exact_matches[0]
@@ -104,7 +131,9 @@ class WorkspaceQueryService:
         suggestions = self._get_fuzzy_suggestions(search_results, query)
         raise exception_class(query, suggestions)
 
-    def _get_fuzzy_suggestions(self, search_results: list[SearchableEntity], query: str) -> list[str]:
+    def _get_fuzzy_suggestions(
+        self, search_results: list[SearchableEntity], query: str
+    ) -> list[str]:
         sorted_by_similarity = find_all_matches(
             query=query,
             items=search_results,
