@@ -1,22 +1,20 @@
 from __future__ import annotations
 
-from collections.abc import AsyncIterator, Callable
+from collections.abc import AsyncIterator
 from typing import TYPE_CHECKING, Self
 
 from notionary.user.service import UserService
 from notionary.workspace.query.builder import NotionWorkspaceQueryConfigBuilder
-from notionary.workspace.query.models import WorkspaceQueryConfig, WorkspaceQueryObjectType
+from notionary.workspace.query.models import (
+    WorkspaceQueryConfig,
+    WorkspaceQueryObjectType,
+)
 from notionary.workspace.query.service import WorkspaceQueryService
 
 if TYPE_CHECKING:
-    from notionary.data_source.service import NotionDataSource
-    from notionary.page.service import NotionPage
+    from notionary import NotionDataSource, NotionPage
     from notionary.user import BotUser, PersonUser
 
-type _QueryConfigInput = (
-    WorkspaceQueryConfig | Callable[[NotionWorkspaceQueryConfigBuilder], NotionWorkspaceQueryConfigBuilder]
-)
-
 
 class NotionWorkspace:
     def __init__(
@@ -41,69 +39,61 @@ class NotionWorkspace:
     def name(self) -> str:
         return self._name
 
+    def get_query_builder(self) -> NotionWorkspaceQueryConfigBuilder:
+        return NotionWorkspaceQueryConfigBuilder()
+
     async def get_pages(
-        self,
-        config: _QueryConfigInput | None = None,
+        self, query_config: WorkspaceQueryConfig | None = None
     ) -> list[NotionPage]:
-        query_config = self._resolve_config(config, WorkspaceQueryObjectType.PAGE)
+        if query_config is None:
+            query_config = WorkspaceQueryConfig(
+                object_type=WorkspaceQueryObjectType.PAGE
+            )
+        else:
+            query_config.object_type = WorkspaceQueryObjectType.PAGE
+
         return await self._query_service.get_pages(query_config)
 
-    async def get_pages_stream(
-        self,
-        config: _QueryConfigInput | None = None,
+    async def iter_pages(
+        self, query_config: WorkspaceQueryConfig | None = None
     ) -> AsyncIterator[NotionPage]:
-        query_config = self._resolve_config(config, WorkspaceQueryObjectType.PAGE)
+        if query_config is None:
+            query_config = WorkspaceQueryConfig(
+                object_type=WorkspaceQueryObjectType.PAGE
+            )
+        else:
+            query_config.object_type = WorkspaceQueryObjectType.PAGE
+
         async for page in self._query_service.get_pages_stream(query_config):
             yield page
 
     async def get_data_sources(
-        self,
-        config: _QueryConfigInput | None = None,
+        self, query_config: WorkspaceQueryConfig | None = None
     ) -> list[NotionDataSource]:
-        query_config = self._resolve_config(config, WorkspaceQueryObjectType.DATA_SOURCE)
+        if query_config is None:
+            query_config = WorkspaceQueryConfig(
+                object_type=WorkspaceQueryObjectType.DATA_SOURCE
+            )
+        else:
+            query_config.object_type = WorkspaceQueryObjectType.DATA_SOURCE
+
         return await self._query_service.get_data_sources(query_config)
 
-    async def get_data_sources_stream(
-        self,
-        config: _QueryConfigInput | None = None,
+    async def iter_data_sources(
+        self, query_config: WorkspaceQueryConfig | None = None
     ) -> AsyncIterator[NotionDataSource]:
-        query_config = self._resolve_config(config, WorkspaceQueryObjectType.DATA_SOURCE)
-        async for data_source in self._query_service.get_data_sources_stream(query_config):
+        if query_config is None:
+            query_config = WorkspaceQueryConfig(
+                object_type=WorkspaceQueryObjectType.DATA_SOURCE
+            )
+        else:
+            query_config.object_type = WorkspaceQueryObjectType.DATA_SOURCE
+
+        async for data_source in self._query_service.get_data_sources_stream(
+            query_config
+        ):
             yield data_source
 
-    def _resolve_config(
-        self,
-        config: _QueryConfigInput | None,
-        expected_object_type: WorkspaceQueryObjectType,
-    ) -> WorkspaceQueryConfig:
-        if config is None:
-            return self._create_default_config(expected_object_type)
-
-        if isinstance(config, WorkspaceQueryConfig):
-            return self._ensure_correct_object_type(config, expected_object_type)
-
-        return self._build_config_from_callable(config, expected_object_type)
-
-    def _create_default_config(self, object_type: WorkspaceQueryObjectType) -> WorkspaceQueryConfig:
-        return WorkspaceQueryConfig(object_type=object_type)
-
-    def _build_config_from_callable(
-        self,
-        config_callable: Callable[[NotionWorkspaceQueryConfigBuilder], NotionWorkspaceQueryConfigBuilder],
-        expected_object_type: WorkspaceQueryObjectType,
-    ) -> WorkspaceQueryConfig:
-        builder = NotionWorkspaceQueryConfigBuilder()
-        config_callable(builder)
-        return self._ensure_correct_object_type(builder.build(), expected_object_type)
-
-    def _ensure_correct_object_type(
-        self,
-        config: WorkspaceQueryConfig,
-        expected_object_type: WorkspaceQueryObjectType,
-    ) -> WorkspaceQueryConfig:
-        config.object_type = expected_object_type
-        return config
-
     async def get_users(self) -> list[PersonUser]:
         return [user async for user in self._user_service.list_users_stream()]
 
